@@ -6,22 +6,22 @@
 
 G_BEGIN_DECLS
 
-/* VOID:VOID (./gstmarshal.list:1) */
+/* VOID:VOID (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:1) */
 #define gst_marshal_VOID__VOID	g_cclosure_marshal_VOID__VOID
 
-/* VOID:BOOLEAN (./gstmarshal.list:2) */
+/* VOID:BOOLEAN (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:2) */
 #define gst_marshal_VOID__BOOLEAN	g_cclosure_marshal_VOID__BOOLEAN
 
-/* VOID:INT (./gstmarshal.list:3) */
+/* VOID:INT (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:3) */
 #define gst_marshal_VOID__INT	g_cclosure_marshal_VOID__INT
 
-/* VOID:STRING (./gstmarshal.list:4) */
+/* VOID:STRING (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:4) */
 #define gst_marshal_VOID__STRING	g_cclosure_marshal_VOID__STRING
 
-/* VOID:BOXED (./gstmarshal.list:5) */
+/* VOID:BOXED (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:5) */
 #define gst_marshal_VOID__BOXED	g_cclosure_marshal_VOID__BOXED
 
-/* VOID:BOXED,OBJECT (./gstmarshal.list:6) */
+/* VOID:BOXED,OBJECT (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:6) */
 extern void gst_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -29,10 +29,10 @@ extern void gst_marshal_VOID__BOXED_OBJECT (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:POINTER (./gstmarshal.list:7) */
+/* VOID:POINTER (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:7) */
 #define gst_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
 
-/* VOID:POINTER,OBJECT (./gstmarshal.list:8) */
+/* VOID:POINTER,OBJECT (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:8) */
 extern void gst_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -40,10 +40,18 @@ extern void gst_marshal_VOID__POINTER_OBJECT (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:OBJECT (./gstmarshal.list:9) */
+/* VOID:OBJECT (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:9) */
 #define gst_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
 
-/* VOID:OBJECT,PARAM (./gstmarshal.list:10) */
+/* VOID:OBJECT,OBJECT (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:10) */
+extern void gst_marshal_VOID__OBJECT_OBJECT (GClosure     *closure,
+                                             GValue       *return_value,
+                                             guint         n_param_values,
+                                             const GValue *param_values,
+                                             gpointer      invocation_hint,
+                                             gpointer      marshal_data);
+
+/* VOID:OBJECT,PARAM (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:11) */
 extern void gst_marshal_VOID__OBJECT_PARAM (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -51,7 +59,7 @@ extern void gst_marshal_VOID__OBJECT_PARAM (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:OBJECT,POINTER (./gstmarshal.list:11) */
+/* VOID:OBJECT,POINTER (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:12) */
 extern void gst_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                               GValue       *return_value,
                                               guint         n_param_values,
@@ -59,7 +67,7 @@ extern void gst_marshal_VOID__OBJECT_POINTER (GClosure     *closure,
                                               gpointer      invocation_hint,
                                               gpointer      marshal_data);
 
-/* VOID:OBJECT,BOXED (./gstmarshal.list:12) */
+/* VOID:OBJECT,BOXED (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:13) */
 extern void gst_marshal_VOID__OBJECT_BOXED (GClosure     *closure,
                                             GValue       *return_value,
                                             guint         n_param_values,
@@ -67,7 +75,7 @@ extern void gst_marshal_VOID__OBJECT_BOXED (GClosure     *closure,
                                             gpointer      invocation_hint,
                                             gpointer      marshal_data);
 
-/* VOID:OBJECT,BOXED,STRING (./gstmarshal.list:13) */
+/* VOID:OBJECT,BOXED,STRING (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:14) */
 extern void gst_marshal_VOID__OBJECT_BOXED_STRING (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -75,7 +83,7 @@ extern void gst_marshal_VOID__OBJECT_BOXED_STRING (GClosure     *closure,
                                                    gpointer      invocation_hint,
                                                    gpointer      marshal_data);
 
-/* VOID:OBJECT,OBJECT,STRING (./gstmarshal.list:14) */
+/* VOID:OBJECT,OBJECT,STRING (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:15) */
 extern void gst_marshal_VOID__OBJECT_OBJECT_STRING (GClosure     *closure,
                                                     GValue       *return_value,
                                                     guint         n_param_values,
@@ -83,7 +91,7 @@ extern void gst_marshal_VOID__OBJECT_OBJECT_STRING (GClosure     *closure,
                                                     gpointer      invocation_hint,
                                                     gpointer      marshal_data);
 
-/* VOID:OBJECT,STRING (./gstmarshal.list:15) */
+/* VOID:OBJECT,STRING (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:16) */
 extern void gst_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                              GValue       *return_value,
                                              guint         n_param_values,
@@ -91,7 +99,7 @@ extern void gst_marshal_VOID__OBJECT_STRING (GClosure     *closure,
                                              gpointer      invocation_hint,
                                              gpointer      marshal_data);
 
-/* VOID:INT,INT (./gstmarshal.list:16) */
+/* VOID:INT,INT (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:17) */
 extern void gst_marshal_VOID__INT_INT (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -99,7 +107,7 @@ extern void gst_marshal_VOID__INT_INT (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* VOID:INT64 (./gstmarshal.list:17) */
+/* VOID:INT64 (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:18) */
 extern void gst_marshal_VOID__INT64 (GClosure     *closure,
                                      GValue       *return_value,
                                      guint         n_param_values,
@@ -107,7 +115,7 @@ extern void gst_marshal_VOID__INT64 (GClosure     *closure,
                                      gpointer      invocation_hint,
                                      gpointer      marshal_data);
 
-/* VOID:UINT,BOXED (./gstmarshal.list:18) */
+/* VOID:UINT,BOXED (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:19) */
 extern void gst_marshal_VOID__UINT_BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -115,10 +123,10 @@ extern void gst_marshal_VOID__UINT_BOXED (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* VOID:UINT,POINTER (./gstmarshal.list:19) */
+/* VOID:UINT,POINTER (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:20) */
 #define gst_marshal_VOID__UINT_POINTER	g_cclosure_marshal_VOID__UINT_POINTER
 
-/* BOOLEAN:VOID (./gstmarshal.list:20) */
+/* BOOLEAN:VOID (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:21) */
 extern void gst_marshal_BOOLEAN__VOID (GClosure     *closure,
                                        GValue       *return_value,
                                        guint         n_param_values,
@@ -126,7 +134,7 @@ extern void gst_marshal_BOOLEAN__VOID (GClosure     *closure,
                                        gpointer      invocation_hint,
                                        gpointer      marshal_data);
 
-/* BOOLEAN:POINTER (./gstmarshal.list:21) */
+/* BOOLEAN:POINTER (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:22) */
 extern void gst_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -134,7 +142,7 @@ extern void gst_marshal_BOOLEAN__POINTER (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* POINTER:POINTER (./gstmarshal.list:22) */
+/* POINTER:POINTER (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:23) */
 extern void gst_marshal_POINTER__POINTER (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -142,7 +150,7 @@ extern void gst_marshal_POINTER__POINTER (GClosure     *closure,
                                           gpointer      invocation_hint,
                                           gpointer      marshal_data);
 
-/* BOXED:BOXED (./gstmarshal.list:23) */
+/* BOXED:BOXED (/usr/obj/i386/gstreamer-0.10.11/gstreamer-0.10.11/gst/gstmarshal.list:24) */
 extern void gst_marshal_BOXED__BOXED (GClosure     *closure,
                                       GValue       *return_value,
                                       guint         n_param_values,
